orbithunter 0.7rc1
==================
orbithunter serves as a framework for solving chaotic nonlinear partial differential equations.

Features
--------

- An object oriented approach to solutions of partial differential equations
- A general-purpose framework for finding, visualizing and manipulating these solutions
- High-level access to SciPy API, particularly its minimize and optimize packages.
- New spatiotemporal techniques such as 'clipping' and 'gluing'

Currently there is only an implementation of the Kuramoto-Sivashinsky equation (KSE).

External Links
--------------

Be sure to check out these resources for help and development!

- `Homepage and Documentation <https://orbithunter.readthedocs.io/en/latest/index.html>`_
- `Issues <https://orbithunter.readthedocs.io/en/latest/issues.html>`_
- `Bug reports <https://github.com/mgudorf/orbithunter/issues>`_
- `Source <https://github.com/mgudorf/orbithunter>`_
- `Developer Guide <https://orbithunter.readthedocs.io/en/latest/guide.html>`_
- `Tutorial Notebooks <https://github.com/mgudorf/orbithunter/tree/main/tutorial>`_
- `FAQ <https://orbithunter.readthedocs.io/en/latest/faq.html>`_

Support
-------

If you are having issues, please let us know.
We have a mailing list located at: orbithunter@googlegroups.com

License
-------

The project is licensed under the GNU General Public License v3 (GPLv3) license.